pub struct NodeGetVolumeStatsRequest {
pub volume_id: String,
pub volume_path: String,
pub staging_target_path: String,
}Fields
volume_id: StringThe ID of the volume. This field is REQUIRED.
volume_path: StringIt can be any valid path where volume was previously staged or published. It MUST be an absolute path in the root filesystem of the process serving this request. This is a REQUIRED field. This field overrides the general CSI size limit. SP SHOULD support the maximum path length allowed by the operating system/filesystem, but, at a minimum, SP MUST accept a max path length of at least 128 bytes.
staging_target_path: StringThe path where the volume is staged, if the plugin has the STAGE_UNSTAGE_VOLUME capability, otherwise empty. If not empty, it MUST be an absolute path in the root filesystem of the process serving this request. This field is OPTIONAL. This field overrides the general CSI size limit. SP SHOULD support the maximum path length allowed by the operating system/filesystem, but, at a minimum, SP MUST accept a max path length of at least 128 bytes.